==> 1.0.19.tar.gz: lib/src/CheckoutPaypalPage.dart <==
import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'ApiService.dart';
import 'Constant/Constant.dart';


class CheckoutPaypalPage extends StatefulWidget {
  final String orderId;
  final String client_id;
  final String transactionId;
  final amount;
  final String merchandUserName;
  final String merchandPassword;
  final String sandbox;
  final String X_API_KEY;
  final String currency;

  const CheckoutPaypalPage({Key key,
    @required this.orderId,
    @required this.client_id,
    @required this.transactionId,
    @required this.amount,
    @required this.merchandUserName,
    @required this.merchandPassword,
    @required this.sandbox,
    @required this.currency,
    @required this.X_API_KEY})
      : super(key: key);

  @override
  _CheckoutPageState createState() => _CheckoutPageState();
}

class _CheckoutPageState extends State<CheckoutPaypalPage> {
  WebViewController _webViewController;
  ApiService api = new ApiService();
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    print("Client Id ${widget.client_id}");
  }
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: false,
      body: SafeArea(
        child: WebView(
          initialUrl: initialUrl,
          javascriptMode: JavascriptMode.unrestricted,
          onWebViewCreated: (webViewController) =>
          _webViewController = webViewController,
          onPageFinished: (String url) {
            if (url == initialUrl) {
              print("onPageFished passed");
            }
          },
          navigationDelegate: (NavigationRequest request) {
            print("The request : $request");
            if (request.url.startsWith('https://success.com')) {
              api.stripeCallBackTransactionIdAndStatus(
                  transactionId: widget.transactionId,
                  transactionStatus: "SUCCESS",
                  context: context,
                  merchandUserName: widget.merchandUserName,
                  merchandPassword: widget.merchandPassword,
                  sandbox: widget.sandbox,
                  X_API_KEY: widget.X_API_KEY);
              Navigator.of(context).pop();
            } else if (request.url.startsWith('https://cancel.com')) {
              api.stripeCallBackTransactionIdAndStatus(
                  transactionId: widget.transactionId,
                  transactionStatus: "FAILED",
                  context: context,
                  merchandUserName: widget.merchandUserName,
                  merchandPassword: widget.merchandPassword,
                  sandbox: widget.sandbox,
                  X_API_KEY: widget.X_API_KEY);
              Navigator.of(context).pop();
            }
            return NavigationDecision.navigate;
          },
        ),
      ),
    );
  }
  String get initialUrl => 'https://hostedpages.payunit.net/#/mobilePayPal?amount=${widget.amount}&transactionId=${widget.transactionId}&order_id=${widget.orderId}&currency=${widget.currency}&client_id=${widget.client_id}';
}

==> 1.0.20.tar.gz: lib/src/CheckoutPaypalPage.dart <==
import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'ApiService.dart';
import 'Constant/Constant.dart';


class CheckoutPaypalPage extends StatefulWidget {
  final String orderId;
  final String client_id;
  final String transactionId;
  final amount;
  final String merchandUserName;
  final String merchandPassword;
  final String sandbox;
  final String X_API_KEY;
  final String currency;
  final Function actionAfterProccess;

  const CheckoutPaypalPage({Key key,
    @required this.orderId,
    @required this.client_id,
    @required this.transactionId,
    @required this.amount,
    @required this.merchandUserName,
    @required this.merchandPassword,
    @required this.sandbox,
    @required this.currency,
    @required this.actionAfterProccess,
    @required this.X_API_KEY})
      : super(key: key);

  @override
  _CheckoutPageState createState() => _CheckoutPageState();
}

class _CheckoutPageState extends State<CheckoutPaypalPage> {
  WebViewController _webViewController;
  ApiService api = new ApiService();
  String get initialUrl => 'https://hostedpages.payunit.net/#/mobilePayPal?amount=${widget.amount}&t_id=${widget.transactionId}&order_id=${widget.orderId}&currency=${widget.currency}&client_id=${widget.client_id}';

  @override
  void initState() {
    super.initState();
    print("This  is the Url paypal url $initialUrl");

  }
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: false,
      body: SafeArea(
        child: WebView(
          initialUrl: initialUrl,
          javascriptMode: JavascriptMode.unrestricted,
          onWebViewCreated: (webViewController) =>
          _webViewController = webViewController,
          onPageFinished: (String url) {
            if (url == initialUrl) {
              print("onPageFished passed");
            }
          },
          navigationDelegate: (NavigationRequest request) {
            print("The request : $request");
            if (request.url.startsWith('https://success.com')) {
              // widget.actionAfterProccess(widget.transactionId,
              //     "SUCCESS");
              Navigator.of(context).pop();
            } else if (request.url.startsWith('https://cancel.com')) {
              // widget.actionAfterProccess(widget.transactionId,
              //     "FAILED");
              Navigator.of(context).pop();
            }
            return NavigationDecision.navigate;
          },
        ),
      ),
    );
  }
}
